@@ -50,7 +50,7 @@ use experimental qw(signatures);
 use Carp qw(cluck croak longmess shortmess);
 
 # Version of this software
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 
 =head1 METHODS
 
@@ -130,13 +130,7 @@ sub _digest($self,$tree,$stash = { depth=>0 }) {
             my @passed_path             =   (@json_path,$child);
             my $depth                   =   $stash->{depth};
             $stash->{_data}->{$child}   =
-                $self->_digest(
-                    $tree->{$child},
-                    { 
-                        path    =>  [@passed_path], 
-                        depth   =>  scalar(@passed_path)
-                    }
-                );
+                $self->_digest_next_node($child,@passed_path);
         }
     }
     elsif   ($type eq 'ARRAY')  {
@@ -148,23 +142,11 @@ sub _digest($self,$tree,$stash = { depth=>0 }) {
             # For this we will change the hash-memory-reference to simply HASH
             if (ref($child) eq 'HASH') {
                 $stash->{_data}->{HASH}     =
-                    $self->_digest(
-                        $child,
-                        { 
-                            path    =>  [@passed_path],
-                            depth   =>  scalar(@passed_path)
-                        }
-                    ); 
+                    $self->_digest_next_node($child,@passed_path);
             }
             else {
                 $stash->{_data}->{$child}   =
-                    $self->_digest(
-                        $child,
-                        { 
-                            path    =>  [@passed_path],
-                            depth   =>  scalar(@passed_path)
-                        }
-                    );
+                    $self->_digest_next_node($child,@passed_path);
             }
         }
     }
@@ -180,6 +162,16 @@ sub _digest($self,$tree,$stash = { depth=>0 }) {
     return $stash;
 }
 
+sub _digest_next_node($self,$child,@passed_path) {
+    return $self->_digest(
+        $child,
+        { 
+            path    =>  [@passed_path],
+            depth   =>  scalar(@passed_path)
+        }
+    );
+}
+
 
 =head1 CORROSPONDANCE
 
